@@ -27,7 +27,7 @@ import fnmatch
 USAGE = """
 \t%prog [OPTIONS] [file1 file2 ... fileN]
 """
-VERSION = '1.6'
+VERSION = '1.7'
 
 misspellings = {}
 exclude_lines = set()
@@ -35,7 +35,9 @@ options = None
 fileopener = None
 quiet_level = 0
 encodings = [ 'utf-8', 'iso-8859-1' ]
-default_dictionary = os.path.join(os.path.dirname(__file__), 'data', 'dictionary.txt')
+# Users might want to link this file into /usr/local/bin, so we resolve the
+# symbolic link path to the real path if necessary.
+default_dictionary = os.path.join(os.path.dirname(os.path.realpath(__file__)), 'data', 'dictionary.txt')
 
 #OPTIONS:
 #
@@ -137,7 +139,7 @@ class FileOpener:
         encoding = self.encdetector.result['encoding']
 
         try:
-            f = open(filename, encoding=encoding)
+            f = open(filename, 'r', encoding=encoding, newline='')
             lines = f.readlines()
         except UnicodeDecodeError:
             print('ERROR: Could not detect encoding: %s' % filename,
@@ -159,7 +161,7 @@ class FileOpener:
 
         while True:
             try:
-                f = open(filename, 'r', encoding=encodings[curr])
+                f = open(filename, 'r', encoding=encodings[curr], newline='')
                 lines = f.readlines()
                 break
             except UnicodeDecodeError:
@@ -178,8 +180,6 @@ class FileOpener:
                 f.close()
 
         if not lines:
-            print('ERROR: Could not detect encoding: %s' % filename,
-                                                        file=sys.stderr)
             raise Exception('Unknown encoding')
 
         encoding = encodings[curr]
@@ -191,9 +191,13 @@ class FileOpener:
 def parse_options(args):
     parser = OptionParser(usage=USAGE, version=VERSION)
 
+    parser.set_defaults(colors = sys.stdout.isatty())
     parser.add_option('-d', '--disable-colors',
-                        action = 'store_true', default = False,
+                        action = 'store_false', dest = 'colors',
                         help = 'Disable colors even when printing to terminal')
+    parser.add_option('-c', '--enable-colors',
+                        action = 'store_true', dest = 'colors',
+                        help = 'Enable colors even when not printing to terminal')
     parser.add_option('-w', '--write-changes',
                         action = 'store_true', default = False,
                         help = 'write changes in place if possible')
@@ -213,9 +217,7 @@ def parse_options(args):
                         help = 'Comma-separated list of files to skip. It '\
                                'accepts globs as well. E.g.: if you want '\
                                'codespell to skip .eps and .txt files, '\
-                               'you\'d give "*.eps,*.txt" to this option. '\
-                               'It is especially useful if you are using in '\
-                               'conjunction with -r option.')
+                               'you\'d give "*.eps,*.txt" to this option.')
 
     parser.add_option('-x', '--exclude-file',
                         help = 'FILE with lines that should not be changed',
@@ -377,7 +379,11 @@ def parse_file(filename, colors, summary):
         lines = f.readlines()
     else:
         # ignore binary files
-        if not istextfile(filename):
+        try:
+            text = istextfile(filename)
+        except FileNotFoundError:
+            return
+        if not text:
             if not quiet_level & QuietLevels.BINARY_FILE:
                 print("WARNING: Binary file: %s " % filename, file=sys.stderr)
             return
@@ -478,7 +484,7 @@ def main(*args):
 
     build_dict(options.dictionary)
     colors = TermColors();
-    if options.disable_colors:
+    if not options.colors:
         colors.disable()
 
     if options.summary:
@@ -511,11 +517,14 @@ def main(*args):
                         i += 1
 
                 for file in files:
-                    if os.path.islink(file):
+                    fname = os.path.join(root, file)
+                    if not os.path.isfile(fname):
+                        continue
+                    if not os.path.getsize(fname):
                         continue
                     if glob_match.match(file):
                         continue
-                    parse_file(os.path.join(root, file), colors, summary)
+                    parse_file(fname, colors, summary)
 
             continue
 
